@@ -42,6 +42,7 @@ class Generator
     mutable std::string d_line;
     bool d_genDebug;
     bool d_printTokens;
+    bool d_threadSafe;
 
     std::unordered_map<std::string, std::string> const &d_polymorphic; 
 
@@ -103,6 +104,7 @@ class Generator
         void lex(std::ostream &out) const;
         void ltype(std::ostream &out) const;
         void ltypeData(std::ostream &out) const;
+        void ltypeClear(std::ostream &out) const;
         void ltypePop(std::ostream &out) const;
         void ltypePush(std::ostream &out) const;
         void ltypeResize(std::ostream &out) const;
@@ -116,19 +118,19 @@ class Generator
         void polymorphicSpecializations(std::ostream &out) const;
         void preIncludes(std::ostream &out) const;
         void print(std::ostream &out) const;
-        void requiredTokens(std::ostream &out) const;
+        void prompt(std::ostream &out) const;
+        void baseClassCode(std::ostream &out) const;
+
         void scannerH(std::ostream &out) const;
         void scannerObject(std::ostream &out) const;
         void staticData(std::ostream &out) const;
         void stype(std::ostream &out) const;
-        void threading(std::ostream &out) const;
         void tokens(std::ostream &out) const;
         void warnTagMismatches(std::ostream &out) const;
 
         void ifInsertStype(bool &accept) const;
         void ifPrintTokens(bool &accept) const;
         void ifLtype(bool &accept) const;
-        void ifThreadSafe(bool &accept) const;
         void atElse(bool &accept) const;
         void atEnd(bool &accept) const;
 
