@@ -4,8 +4,8 @@ void Generator::stype(ostream &out) const
 {
     key(out);
 
-    if (!d_parser.stype().empty())
-        out << d_parser.stype() << '\n';
+    if (!d_options.stype().empty())
+        out << d_options.stype() << '\n';
     else
         out << "typedef int STYPE__;\n";
 }
