@@ -5,7 +5,7 @@ void NonTerminal::undefined(NonTerminal const *nonTerminal)
     if (nonTerminal->isUsed() && !nonTerminal->nProductions())
     {
         s_undefined = true;
-        msg() << "No production rules for non-terminal `" <<
-                 nonTerminal->name() << "'" << err;
+        emsg << "No production rules for non-terminal `" <<
+                 nonTerminal->name() << '\'' << endl;
     }
 }
