@@ -60,6 +60,8 @@ struct Options
         bool        d_polymorphic       = false;
         bool        d_printTokens       = false;
         bool        d_strongTags        = true;
+        bool        d_prompt            = false;
+        bool        d_threadSafe        = false;
     
         size_t      d_requiredTokens = 0;
         size_t      d_stackExpansion = 0;
@@ -145,6 +147,8 @@ struct Options
         void setPolymorphicDecl();
         void setPreInclude();
         void setPrintTokens();
+        void setPrompt();
+        void setThreadSafe();
         void setRequiredTokens(size_t nRequiredTokens);
         void setScannerClassName();
         void setScannerInclude();
@@ -177,6 +181,8 @@ struct Options
         bool lspNeeded() const;
         bool polymorphic() const;
         bool strongTags() const;
+        bool prompt() const;
+        bool threadSafe() const;
 
         OptInfo const &tagMismatches() const;
         OptInfo const &constructorChecks() const;  
@@ -294,6 +300,16 @@ inline std::string const &Options::classSkeleton() const
     return d_classSkeleton;
 }
 
+inline bool Options::prompt() const
+{
+    return d_prompt;
+}
+
+inline bool Options::threadSafe() const
+{
+    return d_threadSafe;
+}
+
 inline bool Options::errorVerbose() const
 {
     return d_errorVerbose;
@@ -394,6 +410,16 @@ inline std::string const &Options::scannerTokenFunction() const
     return d_scannerTokenFunction;
 }
 
+inline void Options::setPrompt()
+{
+    d_prompt = true;
+}
+
+inline void Options::setThreadSafe()
+{
+    d_threadSafe = true;
+}
+
 inline void Options::setBaseClassHeader()
 {
     assign(&d_baseClassHeader, FILENAME, "baseclass-header");
