@@ -5,7 +5,9 @@ void Parser::addPolymorphic(string const &tag, string const &typeSpec)
     if (d_semType != POLYMORPHIC)
         return;
 
-    if (d_polymorphic.find(tag) != d_polymorphic.end())
+    if (typeSpec == "STYPE__")
+        emsg << "Polymorphic type cannot be STYPE__" << endl;
+    else if (d_polymorphic.find(tag) != d_polymorphic.end())
         emsg << "Polymorphic semantic tag `" << tag << "' multiply defined" <<
                 endl;
     else
