@@ -2,6 +2,12 @@
 
 void Parser::expectRules()
 {
+    d_options.setParsingOptions();
+
+        // by default $$ = $1 actions are added when there's no action block.
+    if (d_options.defaultActions().value == Options::UNKNOWN)
+        d_options.setDefaultAction("std", "", 0);
+
     d_scanner.clearBlock();
 
     Terminal::resetPrecedence();    // Incremented terminal priority must be
@@ -12,7 +18,4 @@ void Parser::expectRules()
     // at the end, inspect all nonterminals. if there are any undetermined
     // nonterminals left, change them into true nonterminals.
     d_rules.setNonTerminalTypes();
-
-// not shown in Bisonc++ 2.8.0:
-//    lineMsg(imsg) << "Preamble (until %%) parsed" << endl;
 }
