@@ -3,16 +3,16 @@
 Parser::STYPE__ Parser::handleProductionElements(STYPE__ &first, 
                                                  STYPE__ const &second)
 {
-    if (!first)         // the first PTag was a %prec specification
+    if (not first.valid())      // the first PTag was a %prec specification
         return second;  
-    if (!second)        // the second PTag was a %prec specification:
+    if (not second.valid())     // the second PTag was a %prec specification:
         return first;   // postpone handling of first
 
         // maybe also when currentRule == 0 ? See addProduction
     if (!d_rules.hasRules())    // may happen if the first rule could not be
         return first;           // defined because of token/rulename clash
 
-    switch (first->tag())
+    switch (first.tag())
     {
         case Tag__::TERMINAL:
             d_rules.addElement(first.get<Tag__::TERMINAL>());
