@@ -1,6 +1,6 @@
 #include "production.ih"
 
-Symbol *Production::vectorIdx(size_t/*unsigned*/ idx) const
+Symbol *Production::vectorIdx(size_t idx) const
 {
     return idx >= size() ? 0 : std::vector<Symbol *>::operator[](idx);
 }
