@@ -8,10 +8,11 @@ void Writer::symbolicNames() const
         "\n"
         "SMapVal s_symArr[] =\n"
         "{\n"
-                        // _UNDETERMINED_ is also used in generator/print.cc
-        "    SMapVal(-2, \"_UNDETERMINED_\"),  // predefined symbols\n"
-        "    SMapVal(-1, \"_EOF_\"),\n"
-        "    SMapVal(256, \"_error_\"),\n"
+             // Reserved__::UNDETERMINED__ is also used in generator/print.cc
+        "    SMapVal(-2, \"Reserved__::UNDETERMINED__\"),  "
+                                                    "// predefined symbols\n"
+        "    SMapVal(-1, \"Reserved__::EOF__\"),\n"
+        "    SMapVal(256, \"errTok__\"),\n"
         "\n";
 
     for (auto terminal: d_rules.terminals())
